--- encoding.lua
-- @author senzogawa
-- @release 2010/09/22 0.1.0

require 'nsutf'
--[[ 以下と同様の効果
-- utf8str = nsutf_from_ansi(ansistr)
NL_bind("nsutf.dll", "nsutf_from_ansi", "nsutf_from_ansi")
-- ansistr = nsutf_to_ansi(utf8str)
NL_bind("nsutf.dll", "nsutf_to_ansi", "nsutf_to_ansi")
-- utf8str = nsutf_unescape(escaped_str)
NL_bind("nsutf.dll", "nsutf_unescape", "nsutf_unescape")
-- escaped_str = nsutf_escape(utf8str[, except_ascii=false])
NL_bind("nsutf.dll", "nsutf_escape", "nsutf_escape")
-- version_str = nsutf_version()
NL_bind("nsutf.dll", "nsutf_version", "nsutf_version")
]]

local nsutf_from_ansi = nsutf_from_ansi
local nsutf_to_ansi = nsutf_to_ansi
local nsutf_unescape = nsutf_unescape
local nsutf_escape = nsutf_escape

local assert = assert
local type = type
local module = module

--- SJISとUTF-8文字列を変換する関数を提供します。
module('encoding')


--- SJIS文字コードの文字列をUTF-8に変換します。
-- @usage utf8str = ansi_to_utf8(ansistr)
-- @param ansistr SJIS文字列
-- @return UTF-8文字列
function ansi_to_utf8(ansistr)
  assert(type(ansistr) == "string")
  return nsutf_from_ansi(ansistr)
end


--- UTF-8文字コードの文字列をSJISに変換します。
-- @usage ansistr = utf8_to_ansi(utf8str)
-- @param utf8str UTF-8文字列
-- @return SJIS文字列
function utf8_to_ansi(utf8str)
  assert(type(utf8str) == "string")
  return nsutf_to_ansi(utf8str)
end


--- UTFのエスケープ関数を提供します。
module('encoding.utf')


--- Unicodeエスケープされた文字列をUTF-8文字列に変換します。
-- @usage utf8str = unescape(escaped_str)
-- @param escaped_str Unicodeエスケープされた文字列
-- @return UTF-8文字列
function unescape(escaped_str)
  assert(type(escaped_str) == "string")
  return nsutf_unescape(escaped_str)
end


--- UTF-8文字列をUnicodeエスケープされた文字列に変換します。
-- @usage escaped_str = escape(utf8str[, except_ascii=false])
-- @param utf8str UTF-8文字列
-- @param except_ascii true:ASCIIはエスケープしない、false:ASCIIもエスケープする。
-- @return Unicodeエスケープされた文字列
function escape(utf8str, except_ascii)
  assert(type(utf8str) == "string")
  if except_ascii == nil then
    return nsutf_escape(utf8str)
  end
  assert(type(except_ascii) == "boolean")
  return nsutf_escape(utf8str, except_ascii)
end
